Enum httlib_protos::decoder::DecoderError[][src]

pub enum DecoderError {
    InvalidInput,
    Interrupted,
    InputUnderflow,
    InvalidTag,
}
Contains error options that can be encountered while performing the decoding operations.

Variants

InvalidInput

Indicates that the decoder received an invalid stream of bytes that can not be decoded.

Interrupted

Indicates that the decoder encountered an I/O interruption. Interrupted operations can typically be retried.

InputUnderflow

Indicates that the buffer from which an item was supposed to be decoded does not contain enough octets to complete the decoding.

InvalidTag

Indicates that the decoder encountered an invalid tag number of a key. A tag number must be unique per message and the value can be between 1 and 2^29 - 1.