Enum httlib_protos::decoder::DecoderLit[][src]

pub enum DecoderLit {
Show 27 variants Bytes(Vec<u8>), Bool(Vec<u8>), BoolVec(Vec<u8>), Int32(Vec<u8>), Int32Vec(Vec<u8>), Int64(Vec<u8>), Int64Vec(Vec<u8>), UInt32(Vec<u8>), UInt32Vec(Vec<u8>), UInt64(Vec<u8>), UInt64Vec(Vec<u8>), Float(Vec<u8>), FloatVec(Vec<u8>), Double(Vec<u8>), DoubleVec(Vec<u8>), SInt32(Vec<u8>), SInt32Vec(Vec<u8>), SInt64(Vec<u8>), SInt64Vec(Vec<u8>), Fixed32(Vec<u8>), Fixed32Vec(Vec<u8>), Fixed64(Vec<u8>), Fixed64Vec(Vec<u8>), SFixed32(Vec<u8>), SFixed32Vec(Vec<u8>), SFixed64(Vec<u8>), SFixed64Vec(Vec<u8>),
}
Provides decoder output format options.

This is a list of all binary formats supported by the decoder.

Note that bytes held by each key are considered “safe”. Therefore, we should only pass valid vectors as key arguments when instantiating this object. According to this fact, the ‘std::convert::From’ property is implemented instead of ‘std::convert::TryFrom’.

Variants

Bytes(Vec<u8>)

Represents binary format of wire type 2.

Tuple Fields of Bytes

0: Vec<u8>
Bool(Vec<u8>)

Represents bool format of wire type 0.

Tuple Fields of Bool

0: Vec<u8>
BoolVec(Vec<u8>)

Represents bool format of wire type 2 for packed repeated fields.

Tuple Fields of BoolVec

0: Vec<u8>
Int32(Vec<u8>)

Represents int32 format of wire type 0.

Tuple Fields of Int32

0: Vec<u8>
Int32Vec(Vec<u8>)

Represents int32 format of wire type 0 for packed repeated fields.

Tuple Fields of Int32Vec

0: Vec<u8>
Int64(Vec<u8>)

Represents int64 format of wire type 0.

Tuple Fields of Int64

0: Vec<u8>
Int64Vec(Vec<u8>)

Represents int64 format of wire type 0 for packed repeated fields.

Tuple Fields of Int64Vec

0: Vec<u8>
UInt32(Vec<u8>)

Represents uint32 format of wire type 0.

Tuple Fields of UInt32

0: Vec<u8>
UInt32Vec(Vec<u8>)

Represents uint32 format of wire type 0 for packed repeated fields.

Tuple Fields of UInt32Vec

0: Vec<u8>
UInt64(Vec<u8>)

Represents uint64 format of wire type 0.

Tuple Fields of UInt64

0: Vec<u8>
UInt64Vec(Vec<u8>)

Represents uint64 format of wire type 0 for packed repeated fields.

Tuple Fields of UInt64Vec

0: Vec<u8>
Float(Vec<u8>)

Represents float format of wire type 5.

Tuple Fields of Float

0: Vec<u8>
FloatVec(Vec<u8>)

Represents float format of wire type 5 for packed repeated fields.

Tuple Fields of FloatVec

0: Vec<u8>
Double(Vec<u8>)

Represents uint32 format of wire type 1.

Tuple Fields of Double

0: Vec<u8>
DoubleVec(Vec<u8>)

Represents double format of wire type 1 for packed repeated fields.

Tuple Fields of DoubleVec

0: Vec<u8>
SInt32(Vec<u8>)

Represents sint32 format of wire type 0. Use it when the value is likely to be negative.

Tuple Fields of SInt32

0: Vec<u8>
SInt32Vec(Vec<u8>)

Represents sint32 format of wire type 0 for packed repeated fields. Use it when the values are likely to be negative.

Tuple Fields of SInt32Vec

0: Vec<u8>
SInt64(Vec<u8>)

Represents sint64 format of wire type 0. Use it when the value is likely to be negative.

Tuple Fields of SInt64

0: Vec<u8>
SInt64Vec(Vec<u8>)

Represents sint64 format of wire type 0 for packed repeated fields. Use it when the values are likely to be negative.

Tuple Fields of SInt64Vec

0: Vec<u8>
Fixed32(Vec<u8>)

Represents fixed32 format of wire type 5.

Tuple Fields of Fixed32

0: Vec<u8>
Fixed32Vec(Vec<u8>)

Represents fixed32 format of wire type 5 for packed repeated fields.

Tuple Fields of Fixed32Vec

0: Vec<u8>
Fixed64(Vec<u8>)

Represents fixed64 format of wire type 1.

Tuple Fields of Fixed64

0: Vec<u8>
Fixed64Vec(Vec<u8>)

Represents fixed64 format of wire type 1 for packed repeated fields.

Tuple Fields of Fixed64Vec

0: Vec<u8>
SFixed32(Vec<u8>)

Represents sfixed32 format of wire type 5.

Tuple Fields of SFixed32

0: Vec<u8>
SFixed32Vec(Vec<u8>)

Represents sfixed32 format of wire type 5 for packed repeated fields.

Tuple Fields of SFixed32Vec

0: Vec<u8>
SFixed64(Vec<u8>)

Represents sfixed64 format of wire type 1.

Tuple Fields of SFixed64

0: Vec<u8>
SFixed64Vec(Vec<u8>)

Represents sfixed64 format of wire type 1 for packed repeated fields.

Tuple Fields of SFixed64Vec

0: Vec<u8>