Enum httlib_protos::encoder::EncoderError[][src]

pub enum EncoderError {
    DataOverflow,
    Interrupted,
    InvalidTag,
}
Contains error options that can be encountered while performing the encoding operations.

Variants

DataOverflow

Indicates that the data size limit has been reached.

Interrupted

Indicates that the encoder encountered an I/O interruption. Interrupted operations can typically be retried.

InvalidTag

Indicates that the encoder was unable to proceed due to the key’s invalid tag number. A tag number must be unique per message and the value can be between 1 and 2^29 - 1.