Enum httlib_protos::encoder::EncoderLit[][src]

pub enum EncoderLit<'a> {
Show 27 variants Bytes(&'a Vec<u8>), Bool(&'a bool), BoolVec(&'a Vec<bool>), Int32(&'a i32), Int32Vec(&'a Vec<i32>), Int64(&'a i64), Int64Vec(&'a Vec<i64>), UInt32(&'a u32), UInt32Vec(&'a Vec<u32>), UInt64(&'a u64), UInt64Vec(&'a Vec<u64>), Float(&'a f32), FloatVec(&'a Vec<f32>), Double(&'a f64), DoubleVec(&'a Vec<f64>), SInt32(&'a i32), SInt32Vec(&'a Vec<i32>), SInt64(&'a i64), SInt64Vec(&'a Vec<i64>), Fixed32(&'a u32), Fixed32Vec(&'a Vec<u32>), Fixed64(&'a u64), Fixed64Vec(&'a Vec<u64>), SFixed32(&'a i32), SFixed32Vec(&'a Vec<i32>), SFixed64(&'a i64), SFixed64Vec(&'a Vec<i64>),
}
Provides encoder input format options.

This is a list of all binary formats supported by the encoder.

Variants

Bytes(&'a Vec<u8>)

Represents binary format of wire type 2.

Tuple Fields of Bytes

0: &'a Vec<u8>
Bool(&'a bool)

Represents bool format of wire type 0.

Tuple Fields of Bool

0: &'a bool
BoolVec(&'a Vec<bool>)

Represents bool format of wire type 2 for packed repeated fields.

Tuple Fields of BoolVec

0: &'a Vec<bool>
Int32(&'a i32)

Represents int32 format of wire type 0.

Tuple Fields of Int32

0: &'a i32
Int32Vec(&'a Vec<i32>)

Represents int32 format of wire type 0 for packed repeated fields.

Tuple Fields of Int32Vec

0: &'a Vec<i32>
Int64(&'a i64)

Represents int64 format of wire type 0.

Tuple Fields of Int64

0: &'a i64
Int64Vec(&'a Vec<i64>)

Represents int64 format of wire type 0 for packed repeated fields.

Tuple Fields of Int64Vec

0: &'a Vec<i64>
UInt32(&'a u32)

Represents uint32 format of wire type 0.

Tuple Fields of UInt32

0: &'a u32
UInt32Vec(&'a Vec<u32>)

Represents uint32 format of wire type 0 for packed repeated fields.

Tuple Fields of UInt32Vec

0: &'a Vec<u32>
UInt64(&'a u64)

Represents uint64 format of wire type 0.

Tuple Fields of UInt64

0: &'a u64
UInt64Vec(&'a Vec<u64>)

Represents uint64 format of wire type 0 for packed repeated fields.

Tuple Fields of UInt64Vec

0: &'a Vec<u64>
Float(&'a f32)

Represents float format of wire type 5.

Tuple Fields of Float

0: &'a f32
FloatVec(&'a Vec<f32>)

Represents float format of wire type 5 for packed repeated fields.

Tuple Fields of FloatVec

0: &'a Vec<f32>
Double(&'a f64)

Represents uint32 format of wire type 1.

Tuple Fields of Double

0: &'a f64
DoubleVec(&'a Vec<f64>)

Represents double format of wire type 1 for packed repeated fields.

Tuple Fields of DoubleVec

0: &'a Vec<f64>
SInt32(&'a i32)

Represents sint32 format of wire type 0. Use it when the value is likely to be negative.

Tuple Fields of SInt32

0: &'a i32
SInt32Vec(&'a Vec<i32>)

Represents sint32 format of wire type 0 for packed repeated fields. Use it when the values are likely to be negative.

Tuple Fields of SInt32Vec

0: &'a Vec<i32>
SInt64(&'a i64)

Represents sint64 format of wire type 0. Use it when the value is likely to be negative.

Tuple Fields of SInt64

0: &'a i64
SInt64Vec(&'a Vec<i64>)

Represents sint64 format of wire type 0 for packed repeated fields. Use it when the values are likely to be negative.

Tuple Fields of SInt64Vec

0: &'a Vec<i64>
Fixed32(&'a u32)

Represents fixed32 format of wire type 5.

Tuple Fields of Fixed32

0: &'a u32
Fixed32Vec(&'a Vec<u32>)

Represents fixed32 format of wire type 5 for packed repeated fields.

Tuple Fields of Fixed32Vec

0: &'a Vec<u32>
Fixed64(&'a u64)

Represents fixed64 format of wire type 1.

Tuple Fields of Fixed64

0: &'a u64
Fixed64Vec(&'a Vec<u64>)

Represents fixed64 format of wire type 1 for packed repeated fields.

Tuple Fields of Fixed64Vec

0: &'a Vec<u64>
SFixed32(&'a i32)

Represents sfixed32 format of wire type 5.

Tuple Fields of SFixed32

0: &'a i32
SFixed32Vec(&'a Vec<i32>)

Represents sfixed32 format of wire type 5 for packed repeated fields.

Tuple Fields of SFixed32Vec

0: &'a Vec<i32>
SFixed64(&'a i64)

Represents sfixed64 format of wire type 1.

Tuple Fields of SFixed64

0: &'a i64
SFixed64Vec(&'a Vec<i64>)

Represents sfixed64 format of wire type 1 for packed repeated fields.

Tuple Fields of SFixed64Vec

0: &'a Vec<i64>