Module httlib_protos::decoder [−][src]
Provides an implementation of the proto3 decoder.
The decoder performs the task of translating encoded binary data into actual data fields.
+-------------------+------------------+-------------------+
+ 1. JSON + 2. Transform + 3. Encode + ENCODER
+-------------------+------------------+-------------------+
+ { + + +
+ "name": "John", + 1, John + 0a 04 4a 6f 68 6e +
+ "age": 35 + 2, 35 + 10 23 +
+ } + + +
+-------------------+------------------+-------------------+
+ 6. JSON + 5. Rebuild + 4. Decode + DECODER
+-------------------+------------------+-------------------+The decoder decodes a binary stream back to the original message.
Structs
Provides the decoding engine for Protocol Buffers.
Enums
Contains error options that can be encountered while performing the decoding operations.
Provides decoder output format options.