Enum httlib_protos::decoder::DecoderError [−][src]
pub enum DecoderError {
InvalidInput,
Interrupted,
InputUnderflow,
InvalidTag,
}Expand description
Contains error options that can be encountered while performing the decoding operations.
Variants
Indicates that the decoder received an invalid stream of bytes that can not be decoded.
Indicates that the decoder encountered an I/O interruption. Interrupted operations can typically be retried.
Indicates that the buffer from which an item was supposed to be decoded does not contain enough octets to complete the decoding.
Indicates that the decoder encountered an invalid tag number of a key.
A tag number must be unique per message and the value can be between 1
and 2^29 - 1.